@@ -239,7 +239,9 @@ List EStep(arma::cube x, arma::vec tau, arma::cube Mu, arma::field<arma::mat> Si
     arma::uvec num_posVec = find(seq == seq(pos));
     int num_pos = num_posVec.size();
     if (num_pos > 3){
-      arma::uword q = arma::conv_to<arma::uword>::from(arma::find(lbl == seq(pos)));
+      // arma::uword q = arma::conv_to<arma::uword>::from(arma::find(lbl == seq(pos)));
+      arma::uvec ii = arma::find(lbl == seq(pos), 1, "first");
+      arma::uword q = ii(0);
       arma::vec choice = lbl;
       choice.shed_row(q);
       arma::vec WSS (K);
@@ -322,7 +324,9 @@ List EStep(arma::cube x, arma::vec tau, arma::cube Mu, arma::field<arma::mat> Si
     arma::uvec num_posVec = find(seq == seq(pos));
     int num_pos = num_posVec.size();
     if (num_pos > 3){
-      arma::uword q = arma::conv_to<arma::uword>::from(arma::find(lbl == seq(pos)));
+      // arma::uword q = arma::conv_to<arma::uword>::from(arma::find(lbl == seq(pos)));
+      arma::uvec ii = arma::find(lbl == seq(pos), 1, "first");
+      arma::uword q = ii(0);
       arma::vec choice = lbl;
       choice.shed_row(q);
       arma::vec WSS (K);
@@ -782,8 +786,8 @@ List EMC(arma::cube x, arma::vec tau, arma::cube Mu, arma::field<arma::mat> Sigm
   }
   
   int M = (K - 1) + K*K + 2*K + 3*K*(K-1)/2;
-  double BIC = -2 * ll + M * log(n*(n-1)/2.0);
-  double AIC = -2 * ll + M * 2.0;
+  double BIC = -2 * ll + M * log(n*(n-1)/2);
+  double AIC = -2 * ll + M * 2;
   
   List ret;
   ret["Pi"] = Pi;
@@ -1012,7 +1016,7 @@ List netEM_uni(arma::cube x, int K, double eps, int num_rand_start, int num_run_
   double ll = EMR["ll"];
   
   double M = (K - 1) + K*K + 2*K + K*(K-1) + 0.5*K*(K-1);
-  double BIC = -2 * ll  + M * log(n*(n-1)/2.0);
+  double BIC = -2 * ll  + M * log(n*(n-1)/2);
   
   List ret;
   ret["Pi"] = EMR["Pi"];
@@ -1147,8 +1151,7 @@ double logLindep_mult(arma::field<arma::mat> x, arma::vec tau, arma::field<arma:
       arma::mat xMat = x(i,j);
       arma::rowvec xVec (2*p);
       for (int l=0; l < 2*p; l++){
-        float a = floor(l/2.0);
-        int q = (int) a;
+        int q = floor(l/2);
         int r = l - 2*q;
         xVec(l) = xMat(r,q);
       } 
@@ -1157,8 +1160,7 @@ double logLindep_mult(arma::field<arma::mat> x, arma::vec tau, arma::field<arma:
           arma::mat MuMat = Mu(k,m);
           arma::rowvec MuVec (2*p);
           for (int l=0; l < 2*p; l++){
-            float a = floor(l/2.0);
-            int q = (int) a;
+            int q = floor(l/2);
             int r = l - 2*q;
             MuVec(l) = MuMat(r,q);
           }
@@ -1187,8 +1189,7 @@ List ll_seq_mult(arma::field<arma::mat> x, arma::vec tau, arma::field<arma::mat>
       arma::rowvec xVec (2*p);
       arma::rowvec MuVec (2*p);
       for (int l=0; l < 2*p; l++){
-        float a = floor(l/2.0);
-        int q = (int) a;
+        int q = floor(l/2);
         int r = l - 2*q;
         xVec(l) = xMat(r,q);
         MuVec(l) = MuMat(r,q);
@@ -1240,7 +1241,9 @@ List EStep_mult(arma::field<arma::mat> x, arma::vec tau, arma::field<arma::mat>
     arma::uvec num_posVec = find(seq == seq(pos));
     int num_pos = num_posVec.size();
     if (num_pos > 3){
-      arma::uword q = arma::conv_to<arma::uword>::from(arma::find(lbl == seq(pos)));
+      // arma::uword q = arma::conv_to<arma::uword>::from(arma::find(lbl == seq(pos)));
+      arma::uvec ii = arma::find(lbl == seq(pos), 1, "first");
+      arma::uword q = ii(0);
       arma::vec choice = lbl;
       choice.shed_row(q);
       arma::vec WSS (K);
@@ -1255,8 +1258,7 @@ List EStep_mult(arma::field<arma::mat> x, arma::vec tau, arma::field<arma::mat>
             arma::vec xVec (2*p);
             arma::vec MuVec (2*p);
             for (int l=0; l < 2*p; l++){
-              float a = floor(l/2.0);
-              int q = (int) a;
+              int q = floor(l/2);
               int r = l - 2*q;
               xVec(l) = xMat(r,q);
               MuVec(l) = MuMat(r,q);
@@ -1301,7 +1303,9 @@ List EStep_mult(arma::field<arma::mat> x, arma::vec tau, arma::field<arma::mat>
     arma::uvec num_posVec = find(seq == seq(pos));
     int num_pos = num_posVec.size();
     if (num_pos > 3){
-      arma::uword q = arma::conv_to<arma::uword>::from(arma::find(lbl == seq(pos)));
+      // arma::uword q = arma::conv_to<arma::uword>::from(arma::find(lbl == seq(pos)));
+      arma::uvec ii = arma::find(lbl == seq(pos), 1, "first");
+      arma::uword q = ii(0);
       arma::vec choice = lbl;
       choice.shed_row(q);
       arma::vec WSS (K);
@@ -1316,8 +1320,7 @@ List EStep_mult(arma::field<arma::mat> x, arma::vec tau, arma::field<arma::mat>
             arma::vec xVec (2*p);
             arma::vec MuVec (2*p);
             for (int l=0; l < 2*p; l++){
-              float a = floor(l/2.0);
-              int q = (int) a;
+              int q = floor(l/2);
               int r = l - 2*q;
               xVec(l) = xMat(r,q);
               MuVec(l) = MuMat(r,q);
@@ -1606,8 +1609,7 @@ double logLSeq_mult(arma::field<arma::mat> x, arma::vec tau, arma::field<arma::m
         arma::rowvec xVec (2*p);
         arma::rowvec MuVec (2*p);
         for (int l=0; l < 2*p; l++){
-          float a = floor(l/2.0);
-          int q = (int) a;
+          int q = floor(l/2);
           int r = l - 2*q;
           xVec(l) = xMat(r,q);
           MuVec(l) = MuMat(r,q);
@@ -1841,8 +1843,8 @@ List EMC_mult(arma::field<arma::mat> x, arma::vec tau, arma::field<arma::mat> Mu
   }
   
   int M = (K - 1) + K*K + 2*K + 3*K*(K-1)/2 + K*p*(p-1)/2;
-  double BIC = -2 * ll + M * log(n*(n-1)/2.0);
-  double AIC = -2 * ll + M * 2.0;
+  double BIC = -2 * ll + M * log(n*(n-1)/2);
+  double AIC = -2 * ll + M * 2;
   
   List ret;
   ret["Pi"] = Pi;
@@ -1870,9 +1872,7 @@ List netEM_mult(NumericVector y, int K, int p, double eps, int num_rand_start, i
       int ctr = 0;
       for (int l = 0; l < p; l++){
         for (int k = 0; k < 2; k++){
-          float a = pow(n,2.0);
-          int aa = (int) a;
-          int d = ctr*aa + j*n + i;
+          int d = ctr*pow(n,2) + j*n + i;
           xMat(k,l) = y(d);
           ctr = ctr+1;
         }
@@ -2017,7 +2017,7 @@ List netEM_mult(NumericVector y, int K, int p, double eps, int num_rand_start, i
   double ll = EMR["ll"];
   
   int M = (K - 1) + K*K + 2*K + K*(K-1) + 0.5*K*(K-1) + K*p*(p-1)/2;
-  double BIC = -2 * ll  + M * log(n*(n-1)/2.0);
+  double BIC = -2 * ll  + M * log(n*(n-1)/2);
   
   List ret;
   ret["Pi"] = EMR["Pi"];
@@ -2136,9 +2136,7 @@ List netEM_multilayer(NumericVector y, int K, int p, double eps, int num_rand_st
         int ctr = 0;
         for (int l = 0; l < p; l++){
           for (int k = 0; k < 2; k++){
-            float a = pow(n,2.0);
-            int aa = (int) a;
-            int d = ctr*aa + j*n + i;
+            int d = ctr*pow(n,2) + j*n + i;
             xMat(k,l) = y(d);
             if (xMat(k,l) != 0){
               stop = 1;
